(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common'], factory) :
	(factory((global.angular4datatable = global.angular4datatable || {}),global._angular_core,global._angular_common));
}(this, (function (exports,_angular_core,_angular_common) { 'use strict';

var Direction = {};
Direction.descending = 0;
Direction.ascending = 1;
Direction.notSet = 2;
Direction[Direction.descending] = "descending";
Direction[Direction.ascending] = "ascending";
Direction[Direction.notSet] = "notSet";

var PagerComponent = (function () {
    function PagerComponent() {
        this.onPageIndexChange = new _angular_core.EventEmitter();
        this.itemCount = 0;
        this.activePageIndex = 0;
        this.itemCountPerPage = 10;
    }
    /**
     * @return {?}
     */
    PagerComponent.prototype.ngOnInit = function () {
        this.flushPager(0);
        if (this.itemCount == undefined) {
            this.itemCount = 0;
        }
        if (this.activePageIndex == undefined) {
            this.activePageIndex = 0;
        }
        if (this.itemCountPerPage == undefined) {
            this.itemCountPerPage = 10;
        }
    };
    /**
     * @param {?} index
     * @return {?}
     */
    PagerComponent.prototype.changePage = function (index) {
        this.activePageIndex = index;
        this.flushPager(this.itemCount);
        this.onPageIndexChange.emit(index);
    };
    /**
     * @param {?} index
     * @param {?} itemCount
     * @return {?}
     */
    PagerComponent.prototype.updatePager = function (index, itemCount) {
        this.activePageIndex = index;
        this.itemCount = itemCount;
        this.flushPager(this.itemCount);
        this.onPageIndexChange.emit(index);
    };
    /**
     * @param {?} itemCount
     * @return {?}
     */
    PagerComponent.prototype.flushPager = function (itemCount) {
        console.log(itemCount);
        this.itemCount = itemCount;
        this.totalPages = Math.ceil(this.itemCount / this.itemCountPerPage);
        var /** @type {?} */ step = 2;
        var /** @type {?} */ doubleStep = step * 2;
        var /** @type {?} */ start = Math.max(0, this.activePageIndex - step);
        var /** @type {?} */ end = start + 1 + doubleStep;
        if (end > this.totalPages) {
            end = this.totalPages;
        }
        this.pages = Array();
        for (var /** @type {?} */ i = start; i != end; ++i) {
            this.pages.push(i);
        }
    };
    return PagerComponent;
}());
PagerComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'pager',
                templateUrl: 'app/helpers/pager.component.html'
            },] },
];
/**
 * @nocollapse
 */
PagerComponent.ctorParameters = function () { return []; };
PagerComponent.propDecorators = {
    'onPageIndexChange': [{ type: _angular_core.Output },],
    'itemCount': [{ type: _angular_core.Input },],
    'activePageIndex': [{ type: _angular_core.Input },],
    'itemCountPerPage': [{ type: _angular_core.Input },],
};

var TableStorageManager = (function () {
    function TableStorageManager() {
    }
    /**
     * @return {?}
     */
    TableStorageManager.getInstance = function () {
        if (!TableStorageManager.instance) {
            TableStorageManager.instance = new TableStorageManager();
        }
        return TableStorageManager.instance;
    };
    /**
     * @param {?} table
     * @param {?} tableName
     * @return {?}
     */
    TableStorageManager.prototype.saveFilters = function (table, tableName) {
        var /** @type {?} */ tableAsJson = JSON.stringify(table);
        localStorage.setItem(tableName, tableAsJson);
    };
    /**
     * @param {?} tableName
     * @return {?}
     */
    TableStorageManager.prototype.clearFilters = function (tableName) {
        localStorage.removeItem(tableName);
    };
    /**
     * @param {?} tableName
     * @return {?}
     */
    TableStorageManager.prototype.getFilters = function (tableName) {
        var /** @type {?} */ tableAsJson = localStorage.getItem(tableName);
        var /** @type {?} */ table = JSON.parse(tableAsJson);
        return table;
    };
    return TableStorageManager;
}());

var CustomDataAddingMethod = {};
CustomDataAddingMethod.removeColumnFields = 0;
CustomDataAddingMethod.addToColumnFields = 1;
CustomDataAddingMethod[CustomDataAddingMethod.removeColumnFields] = "removeColumnFields";
CustomDataAddingMethod[CustomDataAddingMethod.addToColumnFields] = "addToColumnFields";

var ValueType = {};
ValueType.text = 0;
ValueType.number = 1;
ValueType.date = 2;
ValueType.none = 3;
ValueType.delimited = 4;
ValueType[ValueType.text] = "text";
ValueType[ValueType.number] = "number";
ValueType[ValueType.date] = "date";
ValueType[ValueType.none] = "none";
ValueType[ValueType.delimited] = "delimited";

// import { ModalComponent } from 'ng2-bs3-modal/ng2-bs3-modal';
var DataTableComponent = (function () {
    function DataTableComponent() {
        this.table = {
            name: "",
            columns: new Array(),
            values: new Array(),
            items: undefined,
            actionColumn: undefined,
            customDetailFields: undefined,
            columnAsDetailField: false,
            detailFields: false,
            detailFieldsAddingMethod: CustomDataAddingMethod.addToColumnFields
        };
        this.onFilterUpdated = new _angular_core.EventEmitter();
        this.onActionClicked = new _angular_core.EventEmitter();
        this.onPageChanged = new _angular_core.EventEmitter();
        this.onSorted = new _angular_core.EventEmitter();
        this.onSearchInputTextChanged = new _angular_core.EventEmitter();
        this.datepickerOpts = {
            autoclose: true,
            todayBtn: 'linked',
            todayHighlight: true,
            assumeNearbyYear: true,
            format: 'yyyy-mm-dd',
            hasClearButton: true,
            placeholder: 'Tarih seç',
            clearBtn: true,
            language: "tr-TR"
        };
        this.loading = false;
        this.anyItem = false;
        this.detailFields = new Array();
        this.lastFilters = new Array();
        this.pageNumber = 0;
        this.pageCount = 10;
    }
    
    /**
     * @return {?}
     */
    DataTableComponent.prototype.ngOnInit = function () { };
    /**
     * @param {?} table
     * @param {?} itemCount
     * @return {?}
     */
    DataTableComponent.prototype.updateTable = function (table, itemCount) {
        this.table = table;
        var /** @type {?} */ storedTable = TableStorageManager.getInstance().getFilters(table.name);
        if (storedTable != undefined) {
            this.setStoredFilters(storedTable);
        }
        if (this.table.columns != undefined) {
            this.setValues();
            if (this.table.detailFields) {
                this.setDetailFields();
            }
        }
        this.itemCount = itemCount;
        if (this.table.items.length > 0) {
            this.anyItem = true;
        }
        else {
            this.anyItem = false;
        }
        this.flushPager();
    };
    /**
     * @param {?} storedTable
     * @return {?}
     */
    DataTableComponent.prototype.setStoredFilters = function (storedTable) {
        this.table.columns.forEach(function (column) {
            var /** @type {?} */ item = storedTable.columns.filter(function (t) { return t.name == column.name; })[0];
            if (item != undefined) {
                if ((item.filter.value != undefined || item.filter.value != "") && column.filter.value != item.filter.value) {
                    if (column.valueType == ValueType.date) {
                        column.filter.value = new Date(item.filter.value);
                    }
                    else if (column.valueType == ValueType.delimited) {
                        column.filter.value = parseInt(item.filter.value);
                    }
                    else {
                        column.filter.value = item.filter.value;
                    }
                }
            }
        });
    };
    /**
     * @return {?}
     */
    DataTableComponent.prototype.setDetailFields = function () {
        var _this = this;
        this.detailFields = new Array();
        if (this.table.columnAsDetailField) {
            this.parseDetailFields();
        }
        else {
            if (this.table.customDetailFields == undefined) {
                this.parseDetailFields();
            }
            else {
                if (this.table.customDetailFields != undefined && this.table.customDetailFields.length > 0) {
                    if (this.table.detailFieldsAddingMethod == CustomDataAddingMethod.addToColumnFields) {
                        this.parseDetailFields();
                        this.table.customDetailFields.forEach(function (element) {
                            _this.detailFields.push(element);
                        });
                    }
                    else if (this.table.detailFieldsAddingMethod == CustomDataAddingMethod.removeColumnFields) {
                        this.detailFields = new Array();
                        this.detailFields = this.table.customDetailFields;
                    }
                }
            }
        }
    };
    /**
     * @param {?} columnName
     * @param {?} items
     * @return {?}
     */
    DataTableComponent.prototype.setDelimitedItemsFor = function (columnName, items) {
        if (this.table != undefined && this.table.columns != undefined && this.table.columns.length > 0) {
            var /** @type {?} */ columns = this.table.columns.filter(function (t) { return t.name == columnName; });
            if (columns.length > 0) {
                var /** @type {?} */ column = columns[0];
                if (column.filter != undefined && column.filter.delimitedFilterFields != undefined && column.filter.isDelimited) {
                    var /** @type {?} */ allItem = {};
                    allItem[column.filter.delimitedFilterFields.displayValueFieldName] = "Tümü";
                    allItem[column.filter.delimitedFilterFields.searchValueFieldName] = -9991;
                    column.filter.delimitedFilterItems = items;
                    column.filter.delimitedFilterItems.splice(0, 0, allItem);
                }
            }
        }
    };
    /**
     * @return {?}
     */
    DataTableComponent.prototype.parseDetailFields = function () {
        var _this = this;
        if (this.table.columns != undefined && this.table.columns.length > 0) {
            var /** @type {?} */ defaultFields = this.detailFields.filter(function (t) { return t.title == 'default'; });
            if (defaultFields.length > 1) {
                this.detailFields.forEach(function (field) {
                    var /** @type {?} */ index = _this.detailFields.indexOf(field);
                    _this.detailFields.splice(index, 1);
                });
            }
            this.detailFields.splice(0, 0, { title: 'default', seperator: false, fields: new Array() });
            this.table.columns.forEach(function (column) {
                var /** @type {?} */ defaultField = _this.detailFields.filter(function (t) { return t.title == 'default'; })[0];
                if (defaultField != undefined) {
                    defaultField.fields.push({
                        valueFieldName: column.valueFieldName,
                        fieldTitle: column.displayName,
                        pipe: column.pipe
                    });
                }
            });
        }
    };
    /**
     * @param {?} $event
     * @param {?} column
     * @return {?}
     */
    DataTableComponent.prototype.dateSelectionChanged = function ($event, column) {
        this.searchInputChanged(column);
    };
    /**
     * @return {?}
     */
    DataTableComponent.prototype.setValues = function () {
        var _this = this;
        this.table.values = new Array();
        this.table.columns.forEach(function (column) {
            if (column.valueFieldName != undefined) {
                _this.table.values.push({
                    name: column.name,
                    value: column.valueFieldName,
                    pipe: column.pipe
                });
            }
        });
    };
    /**
     * @param {?} isLoading
     * @return {?}
     */
    DataTableComponent.prototype.setLoader = function (isLoading) {
        this.loading = isLoading;
    };
    /**
     * @param {?} index
     * @return {?}
     */
    DataTableComponent.prototype.pageChanged = function (index) {
        if (this.pageNumber == index) {
            return;
        }
        this.pageNumber = index;
        this.onPageChanged.emit({ searchFields: this.lastFilters, index: index });
        // this.getItems({ pageIndex: this.pageNumber, pageCount: undefined, searchFields: undefined });
    };
    /**
     * @return {?}
     */
    DataTableComponent.prototype.flushPager = function () {
        if (this.pagerComponent != undefined) {
            this.pagerComponent.updatePager(this.pageNumber, this.itemCount);
        }
    };
    /**
     * @param {?} item
     * @param {?} action
     * @return {?}
     */
    DataTableComponent.prototype.actionClicked = function (item, action) {
        this.onActionClicked.emit({ item: item, action: action });
    };
    /**
     * @param {?} $event
     * @param {?} column
     * @return {?}
     */
    DataTableComponent.prototype.onSelectionChanged = function ($event, column) {
        if ($event == undefined || $event == "undefined") {
            column.filter.value = "";
            this.searchInputChanged(column);
        }
        else {
            column.filter.value = $event;
            this.searchInputChanged(column);
        }
    };
    /**
     * @param {?} column
     * @return {?}
     */
    DataTableComponent.prototype.searchInputChanged = function (column) {
        this.table.columns.forEach(function (clm) {
            if (clm.sort != undefined)
                clm.sort.direction = Direction.notSet;
        });
        var /** @type {?} */ clm = new Array();
        this.table.columns.forEach(function (element) {
            if (element.filter != undefined) {
                if (element.filter.value != undefined && element.filter.value != "") {
                    var /** @type {?} */ value = element.filter.value;
                    if (element.pipe != undefined) {
                        if (element.pipe.args != undefined)
                            value = new element.pipe.pipe().transform(element.filter.value, element.pipe.args);
                        else
                            value = new element.pipe.pipe().transform(element.filter.value);
                    }
                    clm.push({
                        columnName: element.name,
                        value: value == -9991 ? undefined : value
                    });
                    // if(column.valueType == ValueType.Delimited){
                    //     column.filter.value = column.filter.value.toString();
                    // }
                }
            }
        });
        var /** @type {?} */ blankItems = clm.filter(function (t) { return t.value == undefined || t.value == null || Number.isNaN(parseInt(t.value)); });
        if (blankItems.length > 0) {
            blankItems.forEach(function (blankItem) {
                var /** @type {?} */ index = clm.indexOf(blankItem);
                clm.splice(index, 1);
            });
        }
        this.lastFilters = clm;
        TableStorageManager.getInstance().saveFilters(this.table, this.table.name);
        this.onFilterUpdated.emit({ searchFields: clm });
    };
    /**
     * @return {?}
     */
    DataTableComponent.prototype.clearFilters = function () {
        if (this.table.columns != undefined && this.table.columns.length > 0) {
            this.table.columns.forEach(function (column) {
                if (column.filter != undefined) {
                    if (column.valueType == ValueType.delimited) {
                        column.filter.value = undefined;
                        column.filter.value == -9991;
                    }
                    else {
                        column.filter.value = "";
                    }
                }
            });
        }
        TableStorageManager.getInstance().clearFilters(this.table.name);
    };
    /**
     * @param {?} column
     * @return {?}
     */
    DataTableComponent.prototype.sort = function (column) {
        // this.onSorted.emit({ column: column });
        var /** @type {?} */ directionNumber;
        if (column.sort.direction == Direction.ascending) {
            directionNumber = 1;
            column.sort.direction = Direction.descending;
        }
        else if (column.sort.direction == Direction.descending) {
            directionNumber = -1;
            column.sort.direction = Direction.ascending;
        }
        else {
            directionNumber = 1;
            column.sort.direction = Direction.descending;
        }
        //Check property name
        for (var /** @type {?} */ property in this.table.items[0]) {
            if (this.table.items[0].hasOwnProperty(property)) {
                if (property == column.name) {
                    this.table.items.sort(function (a, b) {
                        if (a[property] < b[property])
                            return directionNumber;
                        if (a[property] > b[property])
                            return (directionNumber * -1);
                    });
                }
            }
        }
        this.table.columns.forEach(function (clm) {
            if (clm.name != column.name) {
                if (clm.sort != undefined)
                    clm.sort.direction = Direction.notSet;
            }
        });
    };
    /**
     * @param {?} input
     * @return {?}
     */
    DataTableComponent.prototype.generalSearchInputChanged = function (input) {
        var /** @type {?} */ clm = [
            {
                columnName: "all",
                value: input
            }
        ];
        this.lastFilters = clm;
        this.onSearchInputTextChanged.emit({ column: clm });
    };
    return DataTableComponent;
}());
// showDetail(item: any) {
//     this.selectedItem = item;
//     this.detailModal.open();
// }
DataTableComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'datatable',
                template: "<div class=\"input-icon right\" style=\"float:right;margin:20px 0px\"> <i class=\"icon-magnifier\"></i> <input class=\"form-control form-control-solid input-circle\" placeholder=\"Ara\" [(ngModel)]=\"searchTerm\" (ngModelChange)=\"generalSearchInputChanged($event)\" /> </div> <div class=\"table-scrollable\"> <!-- Table --> <table class=\"table table-striped table-hover table-bordered dataTable no-footer dtr-inline\"> <tr> <th *ngFor=\"let column of table.columns\"> <div> {{column.displayName}} <a *ngIf=\"column.sort\" style=\"float:right;color:black\" (click)=\"sort(column)\"> <label *ngIf=\"column.sort.direction == 0\">↓</label> <label *ngIf=\"column.sort.direction == 1\">↑</label>               <label *ngIf=\"column.sort.direction == 2\">↨</label> </a> </div> <hr style=\"margin:10px 0px\" /> <div *ngIf=\"column.filter\"> <input *ngIf=\"column.valueType == 0 || column.valueType == 1\" class=\"form-control\" [(ngModel)]=\"column.filter.value\" (ngModelChange)=\"searchInputChanged(column)\" style=\"padding:5px;font-weight:500\" placeholder=\"{{column.filter.placeholder}}\" /> <datetime [datepicker]=\"datepickerOpts\" *ngIf=\"column.valueType == 2\" [timepicker]=\"false\" [(ngModel)]=\"column.filter.value\" (ngModelChange)=\"searchInputChanged(column)\" [ngModelOptions]=\"{standalone: true}\"></datetime> <select *ngIf=\"column.valueType == 4\" name=\"filterSelect\" id=\"filterSelect\" (ngModelChange)=\"onSelectionChanged($event,column)\" [(ngModel)]=\"column.filter.value\" class=\"form-control\" [ngModelOptions]=\"{standalone: true}\">                                  <option *ngFor=\"let delimitedItem of column.filter.delimitedFilterItems\" value=\"{{delimitedItem[column.filter.delimitedFilterFields.searchValueFieldName]}}\">{{delimitedItem[column.filter.delimitedFilterFields.displayValueFieldName]}}</option> </select> </div> </th> <th *ngIf=\"table.actionColumn\"> {{table.actionColumn.displayName}} <hr style=\"margin:10px 0px\" /> <div> <div class=\"btn-group\"> <button class=\"btn blue btn-outline btn-circle btn-sm\" type=\"button\" data-toggle=\"dropdown\" aria-expanded=\"true\"> {{table.actionColumn.actionButtonDisplayName}} <i class=\"fa fa-angle-down\"></i> </button> <ul class=\"dropdown-menu\" role=\"menu\"> <li><a href=\"javascript:;\" (click)=\"clearFilters()\"> <i class=\"icon-trash\"></i> Filtreleri Temizle</a></li> </ul> </div> </div> </th> </tr> <template [ngIf]=\"!loading && anyItem\"> <tr *ngFor=\"let item of table.items\"> <td *ngFor=\"let value of table.values\">{{item | columnValue:value}}</td> <td *ngIf=\"table.actionColumn\" style=\"width: 150px\"> <div class=\"btn-group\"> <button class=\"btn blue btn-outline btn-circle btn-sm\" type=\"button\" data-toggle=\"dropdown\" aria-expanded=\"true\"> {{table.actionColumn.actionButtonDisplayName}} <i class=\"fa fa-angle-down\"></i> </button> <ul class=\"dropdown-menu\" role=\"menu\"> <li *ngFor=\"let action of table.actionColumn.actions\"><a href=\"javascript:;\" (click)=\"actionClicked(item,action)\"> <i [ngClass]=\"action.icon\"></i> {{action.displayName}}</a></li> <li *ngIf=\"table.detailFields\"><a href=\"javascript:;\" (click)=\"showDetail(item)\"> <i class=\"fa fa-eye\"></i> Detay</a></li> </ul> </div> </td> </tr> </template> <template [ngIf]=\"loading\"> <tr> <template [ngIf]=\"!table.columns\"> <div class=\"loader-container\"> <div class=\"loader\"></div> </div> </template> <template [ngIf]=\"table.columns\"> <td [colSpan]=\"table.columns.length + 1\"> <div class=\"loader-container\"> <div class=\"loader\"></div> </div> </td> </template> </tr> </template> <template [ngIf]=\"!loading && !anyItem\"> <tr> <td [colSpan]=\"table.columns.length + 1\"> <div style=\"margin:35px 0px\"> <h4 style=\"text-align:center\">Herhangi bir kayıt bulunamadı!</h4> </div> </td> </tr> </template> </table> </div> <div class=\"row\"> <div class=\"col-md-5 col-sm-5\"> <div *ngIf=\"pageCount >= itemCount\" class=\"dataTables_info\">Showing {{itemCount}} of {{itemCount}} entries</div> <div *ngIf=\"pageCount < itemCount\" class=\"dataTables_info\">Showing {{pageNumber*pageCount + 1}} to {{(pageNumber*pageCount + pageCount) > itemCount ? itemCount : pageNumber*pageCount + pageCount}} of {{itemCount}} entries</div> </div> <div class=\"col-md-7 col-sm-7\"> <div class=\"dataTables_paginate paging_bootstrap_number\" id=\"sample_3_paginate\"> <pager (onPageIndexChange)=\"pageChanged($event)\" [itemCount]=\"itemCount\" [activePageIndex]=\"pageNumber\" [itemCountPerPage]=\"pageCount\"></pager> </div> </div> </div> <modal #detailModal> <modal-header> <h4 class=\"modal-title\">Detay</h4> </modal-header> <modal-body> <template [ngIf]=\"selectedItem\"> <div *ngFor=\"let customDetail of detailFields\"> <template [ngIf]=\"customDetail.title == 'default'\"> <div *ngFor=\"let field of customDetail.fields\"> <h5><b>{{field.fieldTitle}}</b></h5> <h5>{{field | detailField:selectedItem}}</h5> </div> </template> <template [ngIf]=\"customDetail.seperator\"> <div> <h3>{{customDetail.title}}</h3> </div> <hr/> <div *ngFor=\"let field of customDetail.fields\"> <h5><b>{{field.fieldTitle}}</b></h5> <h5>{{field | detailField:selectedItem}}</h5> </div> </template> <template [ngIf]=\"!customDetail.seperator && customDetail.title != 'default'\"> <div *ngFor=\"let field of customDetail.fields\"> <h5><b>{{field.fieldTitle}}</b></h5> <h5>{{field | detailField:selectedItem}}</h5> </div> </template> </div> </template> </modal-body> <modal-footer> <button type=\"button\" class=\"btn btn-primary\" (click)=\"detailModal.close()\">Tamam</button> </modal-footer> </modal>"
            },] },
];
/**
 * @nocollapse
 */
DataTableComponent.ctorParameters = function () { return []; };
DataTableComponent.propDecorators = {
    'onFilterUpdated': [{ type: _angular_core.Output },],
    'onActionClicked': [{ type: _angular_core.Output },],
    'onPageChanged': [{ type: _angular_core.Output },],
    'onSorted': [{ type: _angular_core.Output },],
    'onSearchInputTextChanged': [{ type: _angular_core.Output },],
    'pagerComponent': [{ type: _angular_core.ViewChild, args: [PagerComponent,] },],
};

var ColumnValuePipe = (function () {
    function ColumnValuePipe() {
    }
    /**
     * @param {?} item
     * @param {?} value
     * @return {?}
     */
    ColumnValuePipe.prototype.transform = function (item, value) {
        var /** @type {?} */ property = item;
        if (value.value.indexOf(".") != -1) {
            var /** @type {?} */ props = value.value.split(".");
            for (var /** @type {?} */ index = 0; index < props.length; index++) {
                var /** @type {?} */ prop = props[index];
                if (property[prop] != undefined)
                    property = property[prop];
                else
                    property = "";
            }
        }
        else {
            property = property[value.value];
        }
        if (value.pipe != undefined) {
            if (value.pipe.args != undefined)
                property = new value.pipe.pipe().transform(property, value.pipe.args);
            else
                property = new value.pipe.pipe().transform(property);
        }
        return property;
    };
    return ColumnValuePipe;
}());
ColumnValuePipe.decorators = [
    { type: _angular_core.Pipe, args: [{
                name: 'columnValue'
            },] },
];
/**
 * @nocollapse
 */
ColumnValuePipe.ctorParameters = function () { return []; };

var DetailFieldPipe = (function () {
    function DetailFieldPipe() {
    }
    /**
     * @param {?} value
     * @param {?} item
     * @return {?}
     */
    DetailFieldPipe.prototype.transform = function (value, item) {
        var /** @type {?} */ property = item;
        if (value.valueFieldName.indexOf(".") != -1) {
            var /** @type {?} */ props = value.valueFieldName.split(".");
            for (var /** @type {?} */ index = 0; index < props.length; index++) {
                var /** @type {?} */ prop = props[index];
                if (property[prop] != undefined)
                    property = property[prop];
                else
                    property = "";
            }
        }
        else {
            property = property[value.valueFieldName];
        }
        if (value.pipe != undefined) {
            if (value.pipe.args != undefined)
                property = new value.pipe.pipe().transform(property, value.pipe.args);
            else
                property = new value.pipe.pipe().transform(property);
        }
        return property;
    };
    return DetailFieldPipe;
}());
DetailFieldPipe.decorators = [
    { type: _angular_core.Pipe, args: [{
                name: 'detailField'
            },] },
];
/**
 * @nocollapse
 */
DetailFieldPipe.ctorParameters = function () { return []; };

// import { SampleDirective } from './sample.directive';
var DataTableModule = (function () {
    function DataTableModule() {
    }
    /**
     * @return {?}
     */
    DataTableModule.forRoot = function () {
        return {
            ngModule: DataTableModule,
        };
    };
    return DataTableModule;
}());
DataTableModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                imports: [
                    _angular_common.CommonModule
                ],
                declarations: [
                    DataTableComponent,
                    ColumnValuePipe,
                    DetailFieldPipe
                    // SampleDirective,
                    // SamplePipe
                ],
                exports: [
                    DataTableComponent,
                    ColumnValuePipe,
                    DetailFieldPipe
                    // SampleDirective,
                    // SamplePipe
                ]
            },] },
];
/**
 * @nocollapse
 */
DataTableModule.ctorParameters = function () { return []; };

exports.DataTableModule = DataTableModule;
exports.DataTableComponent = DataTableComponent;
exports.ColumnValuePipe = ColumnValuePipe;
exports.DetailFieldPipe = DetailFieldPipe;

Object.defineProperty(exports, '__esModule', { value: true });

})));
